@@ -8,7 +8,7 @@ $VERSION = sprintf "%d.%02d%02d", q/0.1.2/ =~ /(\d+)/g;
 
 %Mail::Mbox::MessageParser::Config = (
   'programs' => {
-    'bzip' => '/usr/local/bin/bzip2',
+    'bzip' => 'bzip2',
     'bzip2' => '/usr/local/bin/bzip2',
     'cat' => '/bin/cat',
     'diff' => '/usr/bin/diff',
@@ -38,3 +38,12 @@ $VERSION = sprintf "%d.%02d%02d", q/0.1.2/ =~ /(\d+)/g;
 
 1;
 
+__END__
+
+# --------------------------------------------------------------------------
+
+=head1 NAME
+
+Mail::Mbox::MessageParser::Config - An internal configuration class
+
+=cut
